@@ -3,11 +3,11 @@ use strict;
 use warnings;
 use Carp ();
 use Class::Load ();
-use DBI 1.33;
+use DBI;
 use Teng::Row;
 use Teng::Iterator;
 use Teng::Schema;
-use DBIx::TransactionManager 1.06;
+use DBIx::TransactionManager 1.02;
 use Teng::QueryBuilder;
 use Class::Accessor::Lite
    rw => [ qw(
@@ -17,14 +17,12 @@ use Class::Accessor::Lite
         schema_class
         suppress_row_objects
         sql_builder
-        sql_comment
         owner_pid
-        mode
-        fields_case
+        driver_name
     )]
 ;
 
-our $VERSION = '0.14_05';
+our $VERSION = '0.01';
 
 sub load_plugin {
     my ($class, $pkg, $opt) = @_;
@@ -37,7 +35,7 @@ sub load_plugin {
           ( $opt->{alias} && $opt->{alias}->{$meth} )
           ? $opt->{alias}->{$meth}
           : $meth;
-        *{"${class}::${dest_meth}"} = $pkg->can($meth);
+        *{"${class}::${dest_meth}"} = *{"${pkg}::$meth"};
     }
 
     $pkg->init($pkg) if $pkg->can('init');
@@ -49,21 +47,17 @@ sub new {
 
     my $self = bless {
         schema_class => "$class\::Schema",
-        owner_pid    => $$,
-        mode         => 'ping',
-        fields_case  => 'NAME_lc',
         %args,
+        owner_pid => $$,
     }, $class;
 
-    my @caller = caller(0);
-    if ($caller[0] ne 'Teng::Schema::Loader' && ! $self->schema) {
-        my $schema_class = $self->{schema_class};
+    if (! $self->schema) {
+        my $schema_class = $self->schema_class;
         Class::Load::load_class( $schema_class );
         my $schema = $schema_class->instance;
         if (! $schema) {
             Carp::croak("schema object was not passed, and could not get schema instance from $schema_class");
         }
-        $schema->namespace($class);
         $self->schema( $schema );
     }
 
@@ -84,8 +78,6 @@ sub new {
 sub connect {
     my ($self, @args) = @_;
 
-    $self->in_transaction_check;
-
     if (@args) {
         $self->connect_info( \@args );
     }
@@ -100,170 +92,84 @@ sub connect {
 
     $self->{dbh} = eval { DBI->connect(@$connect_info) }
         or Carp::croak("Connection error: " . ($@ || $DBI::errstr));
-    delete $self->{txn_manager};
 
-    $self->owner_pid($$);
-
-    $self->_on_connect_do;
-    $self->_prepare_from_dbh;
-}
-
-sub _on_connect_do {
-    my $self = shift;
-
-    if ( my $on_connect_do = $self->on_connect_do ) {
-        if (not ref($on_connect_do)) {
-            $self->do($on_connect_do);
-        } elsif (ref($on_connect_do) eq 'CODE') {
-            $on_connect_do->($self);
-        } elsif (ref($on_connect_do) eq 'ARRAY') {
-            $self->do($_) for @$on_connect_do;
-        } else {
-            Carp::croak('Invalid on_connect_do: '.ref($on_connect_do));
-        }
+    my $on_connect_do = $self->on_connect_do;
+    if (not ref($on_connect_do)) {
+        $self->do($on_connect_do);
+    } elsif (ref($on_connect_do) eq 'CODE') {
+        $on_connect_do->($self);
+    } elsif (ref($on_connect_do) eq 'ARRAY') {
+        $self->do($_) for @$on_connect_do;
+    } else {
+        Carp::croak('Invalid on_connect_do: '.ref($on_connect_do));
     }
+
+    $self->_prepare_from_dbh;
 }
 
 sub reconnect {
     my $self = shift;
-
-    $self->in_transaction_check;
-
-    my $dbh = $self->{dbh};
-
     $self->disconnect();
-
-    if ( @_ ) {
-        $self->connect(@_);
-    }
-    else {
-        # Why don't use $dbh->clone({InactiveDestroy => 0}) ?
-        # because, DBI v1.616 clone with \%attr has bug.
-        # my $dbh2 = $dbh->clone({});
-        # my $dbh3 = $dbh2->clone({});
-        # $dbh2 is ok, but $dbh3 is undef.
-        $self->{dbh} = eval { $dbh->clone }
-            or Carp::croak("ReConnection error: " . ($@ || $DBI::errstr));
-        $self->{dbh}->{InactiveDestroy} = 0;
-
-        $self->owner_pid($$);
-        $self->_on_connect_do;
-        $self->_prepare_from_dbh;
-    }
+    $self->connect(@_);
 }
 
 sub disconnect {
     my $self = shift;
-
-    delete $self->{txn_manager};
-    if ( my $dbh = $self->{dbh} ) {
-        if ( $self->owner_pid && ($self->owner_pid != $$) ) {
-            $dbh->{InactiveDestroy} = 1;
-        }
-        else {
-            $dbh->disconnect;
-        }
-    }
-    $self->owner_pid(undef);
+    $self->{dbh} = undef;
 }
 
 sub _prepare_from_dbh {
     my $self = shift;
 
-    $self->{driver_name} = $self->{dbh}->{Driver}->{Name};
-    my $builder = $self->{sql_builder};
+    $self->driver_name($self->{dbh}->{Driver}->{Name});
+    my $builder = $self->sql_builder;
     if (! $builder ) {
         # XXX Hackish
-        $builder = Teng::QueryBuilder->new(driver => $self->{driver_name} );
+        $builder = Teng::QueryBuilder->new(driver => $self->driver_name );
         $self->sql_builder( $builder );
     }
-    $self->{dbh}->{FetchHashKeyName} = $self->{fields_case};
-
-    $self->{schema}->prepare_from_dbh($self->{dbh}) if $self->{schema};
-}
-
-sub _verify_pid {
-    my $self = shift;
-
-    if ( !$self->owner_pid || $self->owner_pid != $$ ) {
-        $self->reconnect;
-    }
-    elsif ( my $dbh = $self->{dbh} ) {
-        if ( !$dbh->FETCH('Active') ) {
-            $self->reconnect;
-        }
-        elsif ( $self->mode eq 'ping' && !$dbh->ping) {
-            $self->reconnect;
-        }
-    }
 }
 
 sub dbh {
     my $self = shift;
 
-    $self->_verify_pid;
+    if ( $self->owner_pid != $$ ) {
+        $self->owner_pid($$);
+        $self->{dbh}->{InactiveDestroy} = 1;
+        $self->reconnect;
+        return $self->{dbh};
+    }
+
+    unless ($self->{dbh} && $self->{dbh}->FETCH('Active') && $self->{dbh}->ping) {
+        $self->reconnect;
+    }
+
     $self->{dbh};
 }
 
-sub connected {
-    my $self = shift;
-    my $dbh = $self->{dbh};
-    return $self->owner_pid && $dbh->ping;
-}
-
 sub _execute {
-    my ($self, $sql, $binds) = @_;
-
-    if ($ENV{TENG_SQL_COMMENT} || $self->sql_comment) {
-        my $i = 1; # optimize, as we would *NEVER* be called
-        while ( my (@caller) = caller($i++) ) {
-            next if ( $caller[0]->isa( __PACKAGE__ ) );
-            my $comment = "$caller[1] at line $caller[2]";
-            $comment =~ s/\*\// /g;
-            $sql = "/* $comment */\n$sql";
-            last;
-        }
-    }
+    my ($self, $sql, $binds, $table) = @_;
 
     my $sth;
-    eval { $sth = $self->__execute($sql, $binds) };
-
+    eval {
+        $sth = $self->dbh->prepare($sql);
+        $sth->execute(@{$binds || []});
+    };
     if ($@) {
-        if ( $self->mode eq 'fixup' ) {
-            if ( $self->connected ) {
-                $self->handle_error($sql, $binds, $@);
-            }
-            $self->reconnect;
-            eval { $sth = $self->__execute($sql, $binds) };
-            if ($@) {
-                $self->handle_error($sql, $binds, $@);
-            }
-        }
-        else {
-            $self->handle_error($sql, $binds, $@);
-        }
+        $self->handle_error($sql, $binds, $@);
     }
 
-    return $sth;
-}
-
-sub __execute {
-    my ($self, $sql, $binds) = @_;
-
-    my $sth = $self->dbh->prepare($sql);
-    my $i = 1;
-    for my $v ( @{ $binds || [] } ) {
-        $sth->bind_param( $i++, ref($v) ? @$v : $v );
+    if (! defined wantarray ) {
+        $sth->finish;
+        return;
     }
-    $sth->execute();
-
     return $sth;
 }
 
 sub _last_insert_id {
     my ($self, $table_name) = @_;
 
-    my $driver = $self->{driver_name};
+    my $driver = $self->driver_name;
     if ( $driver eq 'mysql' ) {
         return $self->dbh->{mysql_insertid};
     } elsif ( $driver eq 'Pg' ) {
@@ -277,35 +183,18 @@ sub _last_insert_id {
     }
 }
 
-sub _bind_sql_type_to_args {
-    my ( $self, $table, $args ) = @_;
-    my $bind_args = {};
-
-    for my $col (keys %{$args}) {
-        # if $args->{$col} is a ref, it is scalar ref or already
-        # sql type bined parameter. so ignored.
-        $bind_args->{$col} = ref $args->{$col} ? $args->{$col} : [ $args->{$col}, $table->get_sql_type($col) ];
-    }
-
-    return $bind_args;
-}
-
 sub _insert {
     my ($self, $table_name, $args, $prefix) = @_;
 
-    $prefix ||= 'INSERT INTO';
+    $prefix ||= 'INSERT';
     my $table = $self->schema->get_table($table_name);
-    if (! $table) {
-        local $Carp::CarpLevel = $Carp::CarpLevel + 1;
-        Carp::croak( "Table definition for $table_name does not exist (Did you declare it in our schema?)" );
-    }
 
     for my $col (keys %{$args}) {
         $args->{$col} = $table->call_deflate($col, $args->{$col});
     }
-    my $bind_args = $self->_bind_sql_type_to_args( $table, $args );
-    my ($sql, @binds) = $self->{sql_builder}->insert( $table_name, $bind_args, { prefix => $prefix } );
-    $self->_execute($sql, \@binds);
+
+    my ($sql, @binds) = $self->sql_builder->insert( $table_name, $args, { prefix => $prefix } );
+    $self->_execute($sql, \@binds, $table_name);
 }
 
 sub fast_insert {
@@ -328,10 +217,6 @@ sub insert {
 
     return $args if $self->suppress_row_objects;
 
-    if (scalar(@$pk) == 1) {
-        return $self->single($table_name, {$pk->[0] => $args->{$pk->[0]}});
-    }
-
     $table->row_class->new(
         {
             row_data   => $args,
@@ -341,75 +226,28 @@ sub insert {
     );
 }
 
-sub bulk_insert {
-    my ($self, $table_name, $args) = @_;
-
-    return unless scalar(@{$args||[]});
-
-    my $dbh = $self->dbh;
-    my $can_multi_insert = $dbh->{Driver}->{Name} eq 'mysql' ? 1
-                         : $dbh->{Driver}->{Name} eq 'Pg'
-                             && $dbh->{ pg_server_version } >= 82000 ? 1
-                         : 0;
-
-    if ($can_multi_insert) {
-        my $table = $self->schema->get_table($table_name);
-        if (! $table) {
-            Carp::croak( "Table definition for $table_name does not exist (Did you declare it in our schema?)" );
-        }
-
-        if ( $table->has_deflators ) {
-            for my $row (@$args) {
-                for my $col (keys %{$row}) {
-                    $row->{$col} = $table->call_deflate($col, $row->{$col});
-                }
-            }
-        }
-
-        my ($sql, @binds) = $self->sql_builder->insert_multi( $table_name, $args );
-        $self->_execute($sql, \@binds);
-    } else {
-        # use transaction for better performance and atomicity.
-        my $txn = $self->txn_scope();
-        for my $arg (@$args) {
-            # do not run trigger for consistency with mysql.
-            $self->insert($table_name, $arg);
-        }
-        $txn->commit;
-    }
-}
-
-sub _update {
+sub update {
     my ($self, $table_name, $args, $where) = @_;
 
-    my ($sql, @binds) = $self->{sql_builder}->update( $table_name, $args, $where );
-    my $sth = $self->_execute($sql, \@binds);
+    my $table = $self->schema->get_table($table_name);
+
+    for my $col (keys %{$args}) {
+       $args->{$col} = $table->call_deflate($col, $args->{$col});
+    }
+
+    my ($sql, @binds) = $self->sql_builder->update( $table_name, $args, $where );
+    my $sth = $self->_execute($sql, \@binds, $table_name);
     my $rows = $sth->rows;
     $sth->finish;
 
     $rows;
 }
 
-sub update {
-    my ($self, $table_name, $args, $where) = @_;
-
-    my $table = $self->schema->get_table($table_name);
-    if (! $table) {
-        Carp::croak( "Table definition for $table_name does not exist (Did you declare it in our schema?)" );
-    }
-
-    for my $col (keys %{$args}) {
-       $args->{$col} = $table->call_deflate($col, $args->{$col});
-    }
-    
-    $self->_update($table_name, $self->_bind_sql_type_to_args( $table, $args ), $where);
-}
-
 sub delete {
     my ($self, $table_name, $where) = @_;
 
-    my ($sql, @binds) = $self->{sql_builder}->delete( $table_name, $where );
-    my $sth = $self->_execute($sql, \@binds);
+    my ($sql, @binds) = $self->sql_builder->delete( $table_name, $where );
+    my $sth = $self->_execute($sql, \@binds, $table_name);
     my $rows = $sth->rows;
     $sth->finish;
 
@@ -420,59 +258,11 @@ sub delete {
 # for transaction
 sub txn_manager  {
     my $self = shift;
-    $self->_verify_pid;
     $self->{txn_manager} ||= DBIx::TransactionManager->new($self->dbh);
 }
 
-sub in_transaction_check {
-    my $self = shift;
-
-    return unless $self->{txn_manager};
-
-    if ( my $info = $self->{txn_manager}->in_transaction ) {
-        my $caller = $info->{caller};
-        my $pid    = $info->{pid};
-        Carp::confess("Detected transaction during a connect operation (last known transaction at $caller->[1] line $caller->[2], pid $pid). Refusing to proceed at");
-    }
-}
-
-sub txn_scope {
-    my $self = shift;
-    my @caller = caller();
-
-    my $scope;
-    if ( $self->mode eq 'fixup' ) {
-        eval { $scope = $self->txn_manager->txn_scope(caller => \@caller) };
-        if ( $@ ) {
-            if ( $self->connected ) {
-                die $@;
-            }
-            $self->reconnect;
-            $scope = $self->txn_manager->txn_scope(caller => \@caller);
-        }
-    }
-    else {
-        $scope = $self->txn_manager->txn_scope(caller => \@caller);
-    }
-    return $scope;
-}
-
-sub txn_begin {
-    my $self = shift;
-    if ( $self->mode eq 'fixup' ) {
-        eval { $self->txn_manager->txn_begin };
-        if ( $@ ) {
-            if ( $self->connected ) {
-                die $@;
-            }
-            $self->reconnect;
-            $self->txn_manager->txn_begin;
-        }
-    }
-    else {
-        $self->txn_manager->txn_begin;
-    }
-}
+sub txn_scope    { $_[0]->txn_manager->txn_scope    }
+sub txn_begin    { $_[0]->txn_manager->txn_begin    }
 sub txn_rollback { $_[0]->txn_manager->txn_rollback }
 sub txn_commit   { $_[0]->txn_manager->txn_commit   }
 sub txn_end      { $_[0]->txn_manager->txn_end      }
@@ -489,26 +279,17 @@ sub do {
     $ret;
 }
 
-sub _get_select_columns {
-    my ($self, $table, $opt) = @_;
-
-    return $opt->{'+columns'}
-        ? [@{$table->{escaped_columns}{$self->{driver_name}}}, @{$opt->{'+columns'}}]
-        : ($opt->{columns} || $table->{escaped_columns}{$self->{driver_name}})
-    ;
-}
-
 sub search {
     my ($self, $table_name, $where, $opt) = @_;
 
-    my $table = $self->{schema}->get_table( $table_name );
+    my $table = $self->schema->get_table( $table_name );
     if (! $table) {
         Carp::croak("No such table $table_name");
     }
 
-    my ($sql, @binds) = $self->{sql_builder}->select(
+    my ($sql, @binds) = $self->sql_builder->select(
         $table_name,
-        $self->_get_select_columns($table, $opt),
+        $table->columns,
         $where,
         $opt
     );
@@ -538,33 +319,8 @@ sub search_named {
 
 sub single {
     my ($self, $table_name, $where, $opt) = @_;
-
     $opt->{limit} = 1;
-
-    my $table = $self->{schema}->get_table( $table_name );
-    Carp::croak("No such table $table_name") unless $table;
-
-    my ($sql, @binds) = $self->{sql_builder}->select(
-        $table_name,
-        $self->_get_select_columns($table, $opt),
-        $where,
-        $opt
-    );
-    my $sth = $self->_execute($sql, \@binds);
-    my $row = $sth->fetchrow_hashref($self->{fields_case});
-
-    return unless $row;
-    return $row if $self->{suppress_row_objects};
-
-    $table->{row_class}->new(
-        {
-            sql        => $sql,
-            row_data   => $row,
-            teng       => $self,
-            table      => $table,
-            table_name => $table_name,
-        }
-    );
+    $self->search($table_name, $where, $opt)->next;
 }
 
 sub search_by_sql {
@@ -576,10 +332,9 @@ sub search_by_sql {
         teng             => $self,
         sth              => $sth,
         sql              => $sql,
-        row_class        => $self->{schema}->get_row_class($table_name),
-        table            => $self->{schema}->get_table( $table_name ),
+        row_class        => $self->schema->get_row_class($table_name),
         table_name       => $table_name,
-        suppress_object_creation => $self->{suppress_row_objects},
+        suppress_objects => $self->suppress_row_objects,
     );
     return wantarray ? $itr->all : $itr;
 }
@@ -587,7 +342,7 @@ sub search_by_sql {
 sub _guess_table_name {
     my ($class, $sql) = @_;
 
-    if ($sql =~ /\sfrom\s+["`]?([\w]+)["`]?\s*/si) {
+    if ($sql =~ /\sfrom\s+([\w]+)\s*/si) {
         return $1;
     }
     return;
@@ -608,14 +363,6 @@ BIND    : %s
 TRACE
 }
 
-sub DESTROY {
-    my $self = shift;
-
-    if ( $self->owner_pid and $self->owner_pid != $$ and my $dbh = $self->{dbh} ) {
-        $dbh->{InactiveDestroy} = 1;
-    }
-}
-
 1;
 
 __END__
@@ -635,8 +382,6 @@ Teng - very simple DBI wrapper/ORMapper
 Teng is very simple DBI wrapper and simple O/R Mapper.
 It aims to be lightweight, with minimal dependencies so it's easier to install. 
 
-B<THE SOFTWARE IS IT'S IN ALPHA QUALITY. IT MAY CHANGE THE API WITHOUT NOTICE.>
-
 =head1 BASIC USAGE
 
 create your db model base class.
@@ -729,124 +474,68 @@ Teng provides a number of methods to all your classes,
 
 =item $teng = Teng->new(\%args)
 
-Creates a new Teng instance.
+create your teng instance.
 
     # connect new database connection.
-    my $db = Your::Model->new(
-        connect_info => [ $dsn, $username, $password, \%connect_options ]
-    );
-
-Arguments can be:
+    my $db = Your::Model->new(+{
+        dsn      => $dsn,
+        username => $username,
+        password => $password,
+        connect_options => $connect_options,
+    });
 
 =over
 
 =item * C<connect_info>
 
-Specifies the information required to connect to the database.
-The argument should be a reference to a array in the form:
-
-    [ $dsn, $user, $password, \%options ]
-
-You must pass C<connect_info> or C<dbh> to the constructor.
-
-=item * C<dbh>
-
-Specifies the database handle to use. 
-
-=item * C<mode>
-
-=over
-
-=item * C<ping(default)>
-
-reconnect at dbh->ping fail each execute.
-
-=item * C<fixup>
-
-reconnect at fail execute.
-
-=item * C<no_ping>
-
-no auto reconnect.
-
-=item * C<fields_case>
-
-specific DBI.pm's FetchHashKeyName.
-
-=back
+connect_info is [$dsn, $user, $password, $options].
 
 =item * C<schema>
 
-Specifies the Teng::Schema instance to use.
-If not specified, the value specified in C<schema_class> is loaded and 
-instantiated for you.
+specific your schema instance.
+
+by default auto load {YOUR_MODEL_CLASS}::Schema
 
 =item * C<schema_class>
 
-Specifies the schema class to use.
-By default {YOUR_MODEL_CLASS}::Schema is used.
+specific your schema class name space.
+
+by default. {YOUR_MODEL_CLASS}::Schema
 
 =item * C<suppress_row_objects>
 
-Specifies the row object creation mode. By default this value is C<false>.
-If you specifies this to a C<true> value, no row object will be created when
-a C<SELECT> statement is issued..
+set row object creation mode.
+
+if you set off, no creation row object.
 
 =item * C<sql_builder>
 
-Speficies the SQL builder object. By default SQL::Maker is used, and as such,
-if you provide your own SQL builder the interface needs to be compatible
-with SQL::Maker.
+specific your sql builder instance.
 
 =back
 
 =item $row = $teng->insert($table_name, \%row_data)
 
-Inserts a new record. Returns the inserted row object.
+insert new record and get inserted row object.
 
     my $row = $teng->insert('user',{
         id   => 1,
         name => 'nekokak',
     });
 
-If a primary key is available, it will be fetched after the insert -- so
-an INSERT followed by SELECT is performed. If you do not want this, use
-C<fast_insert>.
-
 =item $last_insert_id = $teng->fast_insert($table_name, \%row_data);
 
 insert new record and get last_insert_id.
 
 no creation row object.
 
-=item $teng->bulk_insert($table_name, \@rows_data)
-
-Accepts either an arrayref of hashrefs.
-each hashref should be a structure suitable
-forsubmitting to a Your::Model->insert(...) method.
-
-insert many record by bulk.
-
-example:
-
-    Your::Model->bulk_insert('user',[
-        {
-            id   => 1,
-            name => 'nekokak',
-        },
-        {
-            id   => 2,
-            name => 'yappo',
-        },
-        {
-            id   => 3,
-            name => 'walf443',
-        },
-    ]);
-
 =item $update_row_count = $teng->update($table_name, \%update_row_data, [\%update_condition])
 
-Calls UPDATE on C<$table_name>, with values specified in C<%update_ro_data>, and returns the number of rows updated. You may optionally specify C<%update_condition> to create a conditional update query.
+$update_condition is optional argment.
+
+update record.
+
+example:
 
     my $update_row_count = $teng->update('user',
         {
@@ -856,23 +545,25 @@ Calls UPDATE on C<$table_name>, with values specified in C<%update_ro_data>, and
             id => 1
         }
     );
-    # Executes UPDATE user SET name = 'nomaneko' WHERE id = 1
 
-You can also call update on a row object:
+or 
 
     my $row = $teng->single('user',{id => 1});
     $row->update({name => 'nomaneko'});
 
 =item $delete_row_count = $teng->delete($table, \%delete_condition)
 
-Deletes the specified record(s) from C<$table> and returns the number of rows deleted. You may optionally specify C<%delete_condition> to create a conditional delete query.
+delete record. return delete row count.
 
-    my $rows_deleted = $teng->delete( 'user', {
-        id => 1
-    } );
-    # Executes DELETE FROM user WHERE id = 1
+example:
 
-You can also call delete on a row object:
+    my $delete_row_count = $teng->delete('user',
+        {
+            id => 1,
+        }
+    );
+
+or
 
     my $row = $teng->single('user', {id => 1});
     $row->delete
@@ -932,7 +623,7 @@ So, you can use table row class to search_by_sql result.
 
 =item $teng->txn_scope
 
-Creates a new transaction scope guard object.
+get transaction scope object.
 
     do {
         my $txn = $teng->txn_scope;
@@ -942,6 +633,9 @@ Creates a new transaction scope guard object.
         $txn->commit;
     }
 
+An alternative way of transaction handling based on
+L<DBIx::TransactionManager>.
+
 If an exception occurs, or the guard object otherwise leaves the scope
 before C<< $txn->commit >> is called, the transaction will be rolled
 back by an explicit L</txn_rollback> call. In essence this is akin to
@@ -952,7 +646,7 @@ database disconnection.
 
 =item $txn_manager = $teng->txn_manager
 
-Get the DBIx::TransactionManager instance.
+get DBIx::TransactionManager instance.
 
 =item $teng->txn_begin
 
@@ -970,9 +664,11 @@ rollback transaction.
 
 finish transaction.
 
-=item $teng->do($sql, [\%option, \@bind_values])
+=item $teng->do($sql, [$option, $bind_values])
 
-Execute the query specified by C<$sql>, using C<%option> and C<@bind_values> as necessary. This pretty much a wrapper around L<http://search.cpan.org/dist/DBI/DBI.pm#do>
+execute your query.
+
+See) L<http://search.cpan.org/dist/DBI/DBI.pm#do>
 
 =item $teng->dbh
 
@@ -986,6 +682,14 @@ connect_info is [$dsn, $user, $password, $options].
 
 If you give \@connect_info, create new database connection.
 
+=item $teng->reconnect(\@connect_info)
+
+re connect database handle.
+
+connect_info is [$dsn, $user, $password, $options].
+
+If you give \@connection_info, create new database connection.
+
 =item $teng->disconnect()
 
 Disconnects from the currently connected database.
@@ -1002,22 +706,15 @@ load Teng::Plugin's
 
 handling error method.
 
+=back
+
 =item How do you use display the profiling result?
 
 use L<Devel::KYTProf>.
 
-=back
+=head2 TRIGGER
 
-=head1 TRIGGERS
-
-Teng does not support triggers (NOTE: do not confuse it with SQL triggers - we're talking about Perl level triggers). If you really want to hook into the various methods, use something like L<Moose>, L<Mouse>, and L<Class::Method::Modifiers>.
-
-=head1 SEE ALSO
-
-=head2 Fork
-
-This module was forked from L<DBIx::Skinny>, around version 0.0732.
-many incompatible changes have been made.
+use L<Class::Method::Modifiers>
 
 =head1 BUGS AND LIMITATIONS
 
@@ -1048,5 +745,3 @@ Copyright (c) 2010, the Teng L</AUTHOR>. All rights reserved.
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
-=cut
-
