@@ -5,7 +5,6 @@ use utf8;
 use Carp ();
 use DBI;
 use Teng::Iterator;
-use Data::Page::NoTotalEntries;
 
 our @EXPORT = qw/search_with_pager/;
 
@@ -20,14 +19,9 @@ sub search_with_pager {
         Carp::croak("missing mandatory parameter: $_") unless exists $opt->{$_};
     }
 
-    my $columns = $opt->{'+columns'}
-        ? [@{$table->{columns}}, @{$opt->{'+columns'}}]
-        : ($opt->{columns} || $table->{columns})
-    ;
-
     my ($sql, @binds) = $self->sql_builder->select(
         $table_name,
-        $columns,
+        $table->columns,
         $where,
         +{
             %$opt,
@@ -45,22 +39,44 @@ sub search_with_pager {
         sql              => $sql,
         row_class        => $self->schema->get_row_class($table_name),
         table_name       => $table_name,
-        suppress_object_creation => $self->suppress_row_objects,
+        suppress_objects => $self->suppress_row_objects,
     )->all];
 
     my $has_next = ( $rows + 1 == scalar(@$ret) ) ? 1 : 0;
     if ($has_next) { pop @$ret }
 
-    my $pager = Data::Page::NoTotalEntries->new(
+    my $pager = Teng::Plugin::Pager::Page->new(
         entries_per_page     => $rows,
         current_page         => $page,
         has_next             => $has_next,
-        entries_on_this_page => scalar(@$ret),
+        entries_on_this_page => $sth->rows,
     );
 
     return ($ret, $pager);
 }
 
+package Teng::Plugin::Pager::Page;
+use Class::Accessor::Lite (
+    ro => [qw/entries_per_page current_page has_next entries_on_this_page/],
+);
+
+sub new {
+    my $class = shift;
+    my %args = @_==1 ? %{$_[0]} : @_;
+    bless {%args}, $class;
+}
+
+sub next_page {
+    my $self = shift;
+    $self->has_next ? $self->current_page + 1 : undef;
+}
+
+sub previous_page { shift->prev_page(@_) }
+sub prev_page {
+    my $self = shift;
+    $self->current_page > 1 ? $self->current_page - 1 : undef;
+}
+
 1;
 __END__
 
@@ -110,8 +126,44 @@ The number of entries per page.
 
 =back
 
-This method returns ArrayRef[Teng::Row] and instance of L<Data::Page::NoTotalEntries>.
+This method returns ArrayRef[Teng::Row] and instance of L<Teng::Plugin::Pager::Page>.
 
 =back
 
+=head1 Teng::Plugin::Pager::Page
+
+B<search_with_pager> method returns the instance of Teng::Plugin::Pager::Page. It gives paging information.
+
+=head2 METHODS
+
+=over 4
+
+=item $pager->entries_per_page()
+
+The number of entries per page('rows'. you provided).
+
+=item $pager->current_page()
+
+Returns: fetched page number.
+
+=item $pager->has_next()
+
+The page has next page or not in boolean value.
+
+=item $pager->entries_on_this_page()
+
+How many entries on this page?
+
+=item $pager->next_page()
+
+The page number of next page.
+
+=item $pager->previous_page()
+
+The page number of previous page.
+
+=item $pager->prev_page()
+
+Alias for C<<< $pager->previous_page() >>>.
+
 =back
