@@ -16,14 +16,9 @@ sub search_with_pager {
     my $page = $opt->{page};
     my $rows = $opt->{rows};
 
-    my $columns = $opt->{'+columns'}
-        ? [@{$table->{columns}}, @{$opt->{'+columns'}}]
-        : ($opt->{columns} || $table->{columns})
-    ;
-
     my ($sql, @binds) = $self->sql_builder->select(
         $table_name,
-        $columns,
+        $table->columns,
         $where,
         +{
             %$opt,
@@ -42,7 +37,7 @@ sub search_with_pager {
         sql              => $sql,
         row_class        => $self->schema->get_row_class($table_name),
         table_name       => $table_name,
-        suppress_object_creation => $self->suppress_row_objects,
+        suppress_objects => $self->suppress_row_objects,
     );
 
     my $pager = Data::Page->new();
